==> matita_0.5.3.orig.tar.gz: matita-0.5.3/components/cic_disambiguation/disambiguateChoices.mli <==
(* Copyright (C) 2004, HELM Team.
 * 
 * This file is part of HELM, an Hypertextual, Electronic
 * Library of Mathematics, developed at the Computer Science
 * Department, University of Bologna, Italy.
 * 
 * HELM is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * HELM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HELM; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA  02111-1307, USA.
 * 
 * For details, see the HELM World-Wide-Web page,
 * http://helm.cs.unibo.it/
 *)

open DisambiguateTypes

(** {2 Choice registration low-level interface} *)

  (** raised by lookup_XXXX below *)
exception Choice_not_found of string Lazy.t

  (** register a new number choice *)
val add_num_choice: codomain_item -> unit

(** {2 Choices lookup}
 * for user defined aliases *)

val lookup_num_choices: unit -> codomain_item list

  (** @param dsc description (1st component of codomain_item) *)
val lookup_num_by_dsc: string -> codomain_item

  (** @param symbol symbol as per AST
   * @param dsc description (1st component of codomain_item)
   *)
val lookup_symbol_by_dsc: string -> string -> codomain_item

val mk_choice:
  string * CicNotationPt.argument_pattern list *
  CicNotationPt.cic_appl_pattern ->
    codomain_item

==> matita_0.5.7.orig.tar.gz: matita-0.5.7/components/cic_disambiguation/disambiguateChoices.mli <==
(* Copyright (C) 2004, HELM Team.
 * 
 * This file is part of HELM, an Hypertextual, Electronic
 * Library of Mathematics, developed at the Computer Science
 * Department, University of Bologna, Italy.
 * 
 * HELM is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * HELM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HELM; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA  02111-1307, USA.
 * 
 * For details, see the HELM World-Wide-Web page,
 * http://helm.cs.unibo.it/
 *)

open DisambiguateTypes

(** {2 Choice registration low-level interface} *)

  (** raised by lookup_XXXX below *)
exception Choice_not_found of string Lazy.t

  (** register a new number choice *)
val add_num_choice: Cic.term codomain_item -> unit

(** {2 Choices lookup}
 * for user defined aliases *)

val lookup_num_choices: unit -> Cic.term codomain_item list

  (** @param dsc description (1st component of codomain_item) *)
val lookup_num_by_dsc: string -> Cic.term codomain_item

  (** @param symbol symbol as per AST
   * @param dsc description (1st component of codomain_item)
   *)
val lookup_symbol_by_dsc: 
  mk_appl: ('term list -> 'term) ->
  mk_implicit: (bool -> 'term) ->
  term_of_uri: (UriManager.uri -> 'term) ->
  string -> string -> 'term codomain_item

val cic_lookup_symbol_by_dsc: 
  string -> string -> Cic.term codomain_item

val mk_choice:
  mk_appl: ('term list -> 'term) ->
  mk_implicit: (bool -> 'term) ->
  term_of_uri: (UriManager.uri -> 'term) ->
  string * CicNotationPt.argument_pattern list *
  CicNotationPt.cic_appl_pattern ->
    'term codomain_item
